# BEGIN COPYRIGHT BLOCK
# Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
# Copyright (C) 2005 Red Hat, Inc.
# All rights reserved.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

# END COPYRIGHT BLOCK
#
# Makefile for the Admin Server package
#
#

BUILD_ROOT=$(shell cd ..;pwd)

include $(BUILD_ROOT)/nsconfig.mk
include $(BUILD_ROOT)/components.mk

# Path to Admin Acceptance test.
Admin_ACCEPTANCE_SRV=$(BUILD_ROOT)/../tetframework/testcases/AS/5.0/acceptance/acceptServer
#commented out by kris since we no more using the GUI test
#Admin_ACCEPTANCE=$(BUILD_ROOT)/../tetframework/testcases/AS/4.5/acceptance/accept

# Source directories
JAVADIR=$(BUILD_ROOT)/built/java/$(DIR)

# Destination directories for package
RELTOP=$(BUILD_SHIP)/$(PLATFORM_DEST)
PKGTOP=$(PLATFORM_PACKAGE_DIR)
PKGDIR=$(PLATFORM_PACKAGE_DIR)/admin

ADMIN_JARS=$(BUILD_ROOT)/built/package/java/admin

ADM_CORE=$(DIR)
ADM_CLIENT=client

UNZIPPED_DIR=$(PKGDIR)/unzipped
ADMIN_DIR=$(UNZIPPED_DIR)/$(ADM_CORE)
CLIENT_DIR=$(UNZIPPED_DIR)/$(ADM_CLIENT)

#BASELIB_UNZIPPED_DIR=$(PKGTOP)/base/unzipped/base/lib
#FILTER_DUP_FILES=$(BUILD_ROOT)/admserv/filter-dupfiles.sh

CHMOD=chmod
CPIO=cpio -pdum$(VERBOSE)
MV=mv
MKDIR=mkdir -p
ifeq ($(BUILD_DEBUG), optimize)
ifeq ($(ARCH), IRIX)
STRIP=strip -x
else
STRIP=strip
endif
else
STRIP=true
endif

LWCP = cp      # cp -r behave different on HP

ifeq ($(ARCH), AIX)
export PATH:=/tools/ns-arch/rs6000_ibm_aix3.2.5/bin:/usr/local/aix32/bin:/usr/bin/X11:$(PATH)
export GTAR=/share/builds/f/gtar/bin/aix-gtar
export HTTPDLIB=libnshttpd$(DLL_PRESUF).$(DLL_SUFFIX)
export ADMSERVLIB=libnsadmin$(DLL_PRESUF).$(DLL_SUFFIX)
endif
ifeq ($(ARCH), HPUX)
export PATH:=/usr/local/hpux/bin:/usr/bin/X11:$(PATH)
export GTAR=/share/builds/f/gtar/bin/hpux-gtar
export HTTPDLIB=libnshttpd.sl
export ADMSERVLIB=libnsadmin.sl
LWCP = /usr/local/bin/cp
endif
ifeq ($(ARCH), Linux)
#export PATH:=/bin:/usr/bin:/usr/sbin:/usr/X11R6/bin:$(PATH)
export HTTPDLIB=ns-httpd.so
export ADMSERVLIB=ns-admin.so
endif
ifeq ($(ARCH), OSF1)
export PATH:=/usr/local/dec/bin:/usr/bin/X11:$(PATH)
export GTAR=/share/builds/f/gtar/bin/osf1-gtar
export HTTPDLIB=ns-httpd.so
export ADMSERVLIB=ns-admin.so
endif
ifeq ($(ARCH), SOLARIS)
export PATH:=/usr/ccs/bin:/usr/openwin/bin:$(PATH)
export GTAR=/share/builds/f/gtar/bin/solaris-gtar
export HTTPDLIB=ns-httpd.so
export ADMSERVLIB=ns-admin.so
NO_JAVA=0
endif
ifeq ($(ARCH), SOLARISx86)
export OPENWINHOME:=/usr/openwin
export PATH:=/usr/ccs/bin:/usr/openwin/bin:$(PATH)
export HTTPDLIB=ns-httpd.so
export ADMSERVLIB=ns-admin.so
endif

ifeq ($(ARCH), SOLARISx86)
TAR=/bin/tar
else
TAR=tar
endif

# Temporary disable T zip option (test), as nighty builds are 
# failing because of it. Override IZIP definition in nsdefs.mk.
ifeq ($(ARCH), Linux)
#IZIP  = $(ZIP) -ry9u
IZIP  = $(ZIP) -ry9uT -n .gif
endif

# enable apache module packaging by default - apl is compatible with the gpl
# in this specific instance
PKG_APACHE_MODULES = 1
ifdef PKG_APACHE_MODULES
ifndef MOD_ADMSERV_LIB_DIR
	MOD_ADMSERV_LIB_DIR=$(BUILD_ROOT)/../mod_admserv/.libs
endif
ifndef MOD_RESTARTD_LIB_DIR
	MOD_RESTARTD_LIB_DIR=$(BUILD_ROOT)/../mod_restartd/.libs
endif
ifndef MOD_NSS_LIB_DIR
	MOD_NSS_LIB_DIR=$(BUILD_ROOT)/../mod_nss/.libs
endif
ifndef MOD_NSS_BIN_DIR
	MOD_NSS_BIN_DIR=$(BUILD_ROOT)/../mod_nss
endif
endif

ifneq ($(strip $(ADM_VERSION)),)
all:
	-if [ ! -d $(PKGTOP) ]; then \
	   $(MKDIR) $(PKGTOP) ; \
	fi
ifneq ($(ARCH), WINNT)
	cd $(PKGTOP); find . -type f -exec chmod go-w {} \;
endif
	cd $(PKGTOP); $(TAR) xf $(ADM_RELEASE)/admserv.tar
else

all:  pkguxClient pkguxAdmin pkgSetup pkgSBC

endif

pkguxClient: pkguxConsole $(CLIENT_DIR)
	echo "===== Packaging Admin Server client ======"
	echo
	rm -rf $(CLIENT_DIR)/*
	-$(MKDIR) $(CLIENT_DIR)/java
	-$(MKDIR) $(CLIENT_DIR)/java/jars

# grab the jar files
	cd $(ADMIN_JARS) ; \
	   cp -p admserv$(ADM_SUF).jar admserv$(ADM_SUF)_en.jar $(CLIENT_DIR)/java/jars

#
# Cleanup before making distributable zip
#

	-find $(PKGDIR) -type d -name CVS -prune -exec rm -rf {} \;
	-find $(PKGDIR) -type f \( -name '*.o' -o -name '.*' \) -exec rm {} \;
	-find $(PKGDIR) -type f -exec chmod go-w {} \;
	cd $(CLIENT_DIR) ; \
	   $(IZIP) $(PKGDIR)/ns$(ADM_CLIENT).zip * ;

pkguxConsole:
	cd console; $(MAKE) BUILD_MODULE=HTTP_ADMIN package $(MFLAGS)

pkguxAdmin: $(ADMIN_DIR) new-pkguxAdmin

new-pkguxAdmin:
# Note: need to create $(PKGDIR)/unzipped/admserv for backwards compat --MLM
# Note: need to do admin-nickname rather than admin-serv --MLM

	-$(MKDIR) $(ADMIN_DIR)/dist
	-$(MKDIR) $(ADMIN_DIR)/java/jars
	-$(MKDIR) $(ADMIN_DIR)/java/html/en

	-$(MKDIR) $(ADMIN_DIR)/admin-serv
	-$(MKDIR) $(ADMIN_DIR)/admin-serv/config
	-$(MKDIR) $(ADMIN_DIR)/admin-serv/logs
	-$(MKDIR) $(ADMIN_DIR)/admin-serv/ldif

	-$(MKDIR) $(ADMIN_DIR)/bin/admin
	-$(MKDIR) $(ADMIN_DIR)/bin/admin/lib
	-$(MKDIR) $(ADMIN_DIR)/bin/admin/property
	-$(MKDIR) $(ADMIN_DIR)/bin/admin/admin
	-$(MKDIR) $(ADMIN_DIR)/bin/admin/admin/icons

	-$(MKDIR) $(ADMIN_DIR)/bin/user
	-$(MKDIR) $(ADMIN_DIR)/bin/user/admin
	-$(MKDIR) $(ADMIN_DIR)/bin/user/admin/bin
	-$(MKDIR) $(ADMIN_DIR)/bin/user/admin/gifs
	-$(MKDIR) $(ADMIN_DIR)/bin/user/admin/html/en

	-$(MKDIR) $(ADMIN_DIR)/manual

	-$(MKDIR) $(ADMIN_DIR)/setup
	-$(MKDIR) $(ADMIN_DIR)/setup/admin

	-$(MKDIR) $(ADMIN_DIR)/clients

# richm - new - for admin_ip.pl
	-$(MKDIR) $(ADMIN_DIR)/shared
	-$(MKDIR) $(ADMIN_DIR)/shared/bin
# for certmap.conf
	-$(MKDIR) $(ADMIN_DIR)/shared/config
	-$(MKDIR) $(ADMIN_DIR)/shared/config/template

	cp -p $(ADMSERV_OBJDIR)/cgi/bin/download $(ADMIN_DIR)/dist

	cd $(ADMSERV_OBJDIR)/install/bin ; \
	cp -p ns-config $(ADMIN_DIR)/bin/admin ; \
	cp -p ns-update $(ADMIN_DIR)/bin/admin ; \
	cp -p ns-remove $(ADMIN_DIR)/bin/admin

# Handle "lib" directory
# Copy LDAP SDK
	cd $(LDAPSDK_LIBPATH); cp -p $(LDAP_SOLIBS) $(ADMIN_DIR)/bin/admin/lib

# Copy NSPR SDK
	cd $(NSPR_LIBPATH); cp -p $(NSPR_SOLIBS) $(ADMIN_DIR)/bin/admin/lib
#
# Copy SECURITY SDK
	cd $(SECURITY_LIBPATH); cp -p $(SECURITY_SOLIBS) $(ADMIN_DIR)/bin/admin/lib

# Copy LIB ICU
	cd $(ICU_LIBPATH); cp -p $(ICU_SOLIBS) $(ADMIN_DIR)/bin/admin/lib

# Cert System needs chk files [154431]
	cd $(NSPR_LIBPATH); cp -p libsoftokn3.chk $(ADMIN_DIR)/bin/admin/lib
# libfreebl_*.chk files only exist on the 32-bit builds.
# They should be packaged only for the 32-bit builds.
ifneq ($(USE_64), 1)
ifeq ($(ARCH), SOLARIS)
	cd $(NSPR_LIBPATH); cp -p libfreebl_*.chk $(ADMIN_DIR)/bin/admin/lib
endif
ifeq ($(ARCH), HPUX)
	cd $(NSPR_LIBPATH); cp -p libfreebl_*.chk $(ADMIN_DIR)/bin/admin/lib
endif
endif

# Copy LIB ADMIN UTIL
	cd $(ADMINUTIL_LIBPATH); cp -p $(ADMINUTIL_SOLIBS) $(ADMIN_DIR)/bin/admin/lib
	if [ -d $(ADMINUTIL_LIBPATH)/property ] ; then \
		$(MKDIR) $(ADMIN_DIR)/bin/admin/lib/property ; \
		cp -p $(ADMINUTIL_LIBPATH)/property/* $(ADMIN_DIR)/bin/admin/lib/property ; \
	elif [ -d $(ADMINUTIL_LIBPATH)/adminutil-properties ] ; then \
		$(MKDIR) $(ADMIN_DIR)/bin/admin/lib/adminutil-properties ; \
		cp -p $(ADMINUTIL_LIBPATH)/adminutil-properties/* $(ADMIN_DIR)/bin/admin/lib/adminutil-properties ; \
	fi

	cd $(ADMSERV_OBJDIR)/cmdln; \
	cp -p admconfig $(ADMIN_DIR)/bin/admin;

	cd $(ADMIN_JARS)/.. ; \
	   find *.html *.gif *.jpg | $(CPIO) $(ADMIN_DIR)/java/html
	cd $(ADMIN_JARS)/.. ; \
	   find *.html | $(CPIO) $(ADMIN_DIR)/java/html/en

	cp $(BUILD_ROOT)/lib/ldaputil/certmap.conf $(ADMIN_DIR)/shared/config
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/httpd.conf $(ADMIN_DIR)/shared/config/template/httpd.conf.tmpl
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/admserv.conf $(ADMIN_DIR)/shared/config/template/admserv.conf.tmpl
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/console.conf $(ADMIN_DIR)/shared/config/template/console.conf.tmpl
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/nss.conf $(ADMIN_DIR)/shared/config/template/nss.conf.tmpl
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/start-admin $(ADMIN_DIR)/shared/config/template/start-admin.tmpl
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/stop-admin $(ADMIN_DIR)/shared/config/template/stop-admin.tmpl
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/restart-admin $(ADMIN_DIR)/shared/config/template/restart-admin.tmpl

#   The patch file that upgrades 1.0 to 1.0.1
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/adminserver10to101.patch $(ADMIN_DIR)/setup
#   The patch file that fixes the start-admin ldap problem on Fedora Core 2
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/adminserver-start-admin.patch $(ADMIN_DIR)/setup
#   The patch file that fixes the console ld libpath problem
	cp -p $(BUILD_ROOT)/admserv/cfgstuff/console-ld-libpath.patch $(ADMIN_DIR)/setup

	cp -p $(BUILD_ROOT)/admserv/newinst/common/config/not_installed.html $(ADMIN_DIR)/clients

	cd $(ADMSERV_OBJDIR)/cgi ; \
	   find html bin -print | \
	      $(CPIO) $(ADMIN_DIR)/bin/admin/admin

	rm -f $(ADMIN_DIR)/bin/admin/admin/bin/download

	cd $(ADMSERV_OBJDIR)/cgi/icons40 ; \
	cp -p * $(ADMIN_DIR)/bin/admin/admin/icons;

	cd $(ADMSERV_OBJDIR)/manual ; \
		find help -print | \
			$(CPIO) $(ADMIN_DIR)/manual

ifdef ONLINEHELP_SOURCE_DIR
	@cd $(ONLINEHELP_SOURCE_DIR)/adminconsole/html ; \
	for dir in * ; do \
		if [ $$dir != "CVS" ] ; then \
			mkdir -p $(ADMIN_DIR)/manual/$$dir/admin ; \
			cd $$dir ; \
			find * -name CVS -prune -o -print | $(CPIO) $(ADMIN_DIR)/manual/$$dir/admin ; \
			cd .. ; \
		fi ; \
	done
else
	(cd $(ADMIN_DIR)/manual; $(UNZIP) -o $(ADMDOC_PATH)/$(ADMDOC_ADMONLINEHELP))
endif

#	cat $(ADMSERV_OBJDIR)/ldif/tasks.ldif $(ADMSERV_OBJDIR)/ldif/unixtasks.ldif > $(ADMIN_DIR)/admin-serv/ldif/tasks.ldif
	cp -p $(ADMSERV_OBJDIR)/ldif/tasks.ldif $(ADMIN_DIR)/admin-serv/ldif
	cp -p $(ADMSERV_OBJDIR)/ldif/global.ldif $(ADMIN_DIR)/admin-serv/ldif

# Copy admin_ip.pl (see bug#357241)
	cp -p $(ADMSERV_OBJDIR)/cgi/cfgstuff/admin_ip.pl $(ADMIN_DIR)/shared/bin

# Copy shared configuration
	cp $(BUILD_ROOT)/lib/ldaputil/certmap.conf $(ADMIN_DIR)/shared/config

# The Apache modules, if present
ifdef PKG_APACHE_MODULES
	cp $(MOD_ADMSERV_LIB_DIR)/libmodadmserv.$(DLL_SUFFIX) $(ADMIN_DIR)/bin/admin/lib
	cp $(MOD_RESTARTD_LIB_DIR)/libmodrestartd.$(DLL_SUFFIX) $(ADMIN_DIR)/bin/admin/lib
	cp $(MOD_NSS_LIB_DIR)/libmodnss.$(DLL_SUFFIX) $(ADMIN_DIR)/bin/admin/lib
	cp $(MOD_NSS_BIN_DIR)/nss_pcache $(ADMIN_DIR)/bin/admin/admin/bin
endif

#
# Cleanup before making distributable tar
#

	-find $(PKGDIR) -type d -name CVS -prune -exec rm -rf {} \;
	-find $(PKGDIR) -type f \( -name '*.o' -o -name '.*' \) -exec rm {} \;

	-$(STRIP) $(ADMIN_DIR)/bin/admin/*
	-$(STRIP) $(ADMIN_DIR)/bin/admin/admin/bin/*
	-$(STRIP) $(ADMIN_DIR)/bin/user/admin/bin/*
	-$(STRIP) $(ADMIN_DIR)/dist/*
	-$(STRIP) $(ADMIN_DIR)/manual/help/*
	-find $(PKGDIR) -type f -exec chmod go-w {} \;

	cd $(ADMIN_DIR) ; \
	   $(IZIP) $(PKGDIR)/ns$(DIR).zip * ;

	if [ -f $(ADMSERV_OBJDIR)/$(ADM_CORE).inf ]; then \
	   cp -p $(ADMSERV_OBJDIR)/$(ADM_CORE).inf $(PKGDIR) ; \
        fi

	cp -p $(ADMIN_DIR)/bin/admin/ns-config $(PKGDIR)

pkgSetup:
	-find $(PKGDIR) -name setup -prune -exec rm -f {} \;
	-find $(PKGDIR) -name setup.inf -prune -exec rm -f {} \;
	-find $(PKGDIR) -name LICENSE.txt -prune -exec rm -f {} \;
	-find $(PKGDIR) -name README.txt  -prune -exec rm -f {} \;

	-if [ ! -d $(PKGTOP)/svrcore ]; then \
	   $(MKDIR) $(PKGTOP)/svrcore; \
	else \
	   rm -rf $(PKGTOP)/svrcore/*; \
	fi

	cp -p $(SETUPUTIL_BIN)/setup $(PKGTOP)
	cp -p $(SETUPUTIL_BIN)/setup.inf $(PKGTOP)
	cp -p $(ADMSERV_OBJDIR)/LICENSE.txt $(PKGTOP)
	cp -p $(ADMSERV_OBJDIR)/README.txt $(PKGTOP)
	cp -p $(SETUPUTIL_BIN)/unzip_wrapper.pl $(PKGTOP)

	cd $(SETUPUTIL_BIN)/svrcore ; \
	   find * -print | \
	      $(CPIO) $(PKGTOP)/svrcore


#
# Creating unzipped directory
#
$(ADMIN_DIR):
	-if [ ! -d $(ADMIN_DIR) ]; then \
	   $(MKDIR) $(ADMIN_DIR) ; \
	else \
	   rm -f $(PKGDIR)/$(ADM_CORE).inf; \
	   rm -f $(ADMIN_DIR)/ns$(ADM_CORE).zip ; \
	fi

$(CLIENT_DIR):
	-if [ ! -d $(CLIENT_DIR) ]; then \
	   $(MKDIR) $(CLIENT_DIR) ; \
	else \
	   rm -f $(PKGDIR)/ns$(ADM_CLIENT).zip ; \
	fi

#
# For SNMP Plugins
#
pkguxSNMP:
	-$(MKDIR) $(ADMIN_DIR)/plugins/snmp/magt
	-$(MKDIR) $(ADMIN_DIR)/plugins/snmp/sagt
	if [ -f $(BUILD_ROOT)/lib/libsnmp/netscape-main.mib ]; then \
	   cd $(BUILD_ROOT)/lib/libsnmp ; \
	   cp -p netscape-main.mib $(ADMIN_DIR)/plugins/snmp/netscape-main.mib ; \
	fi
	cd $(DEVROOT)/$(NSOBJDIR_NAME) ; \
	   find magt sagt -print | $(CPIO) $(ADMIN_DIR)/plugins/snmp
	-$(STRIP) $(ADMIN_DIR)/plugins/snmp/magt/*
	-$(STRIP) $(ADMIN_DIR)/plugins/snmp/sagt/*

pkgSBC:
ifneq ($(ARCH), WINNT)
	cd $(PKGTOP); find . -type f -exec chmod go-w {} \;
endif
ifdef BUILD_SHIP
	-$(MKDIR) $(RELTOP)
	-rm $(RELTOP)/admserv.ex
	echo "base/unzipped" > $(RELTOP)/admserv.ex
	echo "admin/unzipped" >> $(RELTOP)/admserv.ex
	echo "svrcore/unzipped" >> $(RELTOP)/admserv.ex
	cd $(PKGTOP); $(TAR) cvfX $(RELTOP)/admserv.tar $(RELTOP)/admserv.ex *
	-rm  $(RELTOP)/admserv.tar.gz $(RELTOP)/admserv.ex
	cd $(RELTOP); gzip -f admserv.tar
endif      

Acceptance:

ifdef BUILD_SHIP
ifeq ($(BUILD_SECURITY), domestic)
ifeq ($(BUILD_DEBUG), optimize)
#	$(Admin_ACCEPTANCE) $(RELTOP)/admserv.tar.gz
	$(Admin_ACCEPTANCE_SRV) $(RELTOP)/admserv.tar.gz
endif  # optimize
endif  # domestic
endif  # BUILD_SHIP
